@@ -1,61 +1,88 @@
 #' Bayes Factors (BF) for a Single Parameter
 #'
-#' This method computes Bayes factors against the null (either a point or an interval),
-#' based on prior and posterior samples of a single parameter. This Bayes factor indicates
-#' the degree by which the mass of the posterior distribution has shifted further away
-#' from or closer to the null value(s) (relative to the prior distribution), thus indicating
-#' if the null value has become less or more likely given the observed data.
+#' This method computes Bayes factors against the null (either a point or an
+#' interval), based on prior and posterior samples of a single parameter. This
+#' Bayes factor indicates the degree by which the mass of the posterior
+#' distribution has shifted further away from or closer to the null value(s)
+#' (relative to the prior distribution), thus indicating if the null value has
+#' become less or more likely given the observed data.
 #' \cr \cr
-#' When the null is an interval, the Bayes factor is computed by comparing the prior
-#' and posterior odds of the parameter falling within or outside the null interval
-#' (Morey & Rouder, 2011; Liao et al., 2020); When the null is a point, a Savage-Dickey
-#' density ratio is computed, which is also an approximation of a Bayes factor comparing
-#' the marginal likelihoods of the model against a model in which the tested parameter
-#' has been restricted to the point null (Wagenmakers et al., 2010; Heck, 2019).
+#' When the null is an interval, the Bayes factor is computed by comparing the
+#' prior and posterior odds of the parameter falling within or outside the null
+#' interval (Morey & Rouder, 2011; Liao et al., 2020); When the null is a point,
+#' a Savage-Dickey density ratio is computed, which is also an approximation of
+#' a Bayes factor comparing the marginal likelihoods of the model against a
+#' model in which the tested parameter has been restricted to the point null
+#' (Wagenmakers et al., 2010; Heck, 2019).
 #' \cr \cr
-#' Note that the \code{logspline} package is used for estimating densities and probabilities,
-#' and must be installed for the function to work.
+#' Note that the \code{logspline} package is used for estimating densities and
+#' probabilities, and must be installed for the function to work.
 #' \cr \cr
-#' \code{bayesfactor_pointnull()} and \code{bayesfactor_rope()} are wrappers around
-#' \code{bayesfactor_parameters} with different defaults for the null to be tested against
-#' (a point and a range, respectively). Aliases of the main functions are prefixed
-#' with \code{bf_*}, like \code{bf_parameters()} or \code{bf_pointnull()}
+#' \code{bayesfactor_pointnull()} and \code{bayesfactor_rope()} are wrappers
+#' around \code{bayesfactor_parameters} with different defaults for the null to
+#' be tested against (a point and a range, respectively). Aliases of the main
+#' functions are prefixed with \code{bf_*}, like \code{bf_parameters()} or
+#' \code{bf_pointnull()}.
 #' \cr \cr
-#' \strong{For more info, in particular on specifying correct priors for factors with more than 2 levels, see \href{https://easystats.github.io/bayestestR/articles/bayes_factors.html}{the Bayes factors vignette}.}
+#' \strong{For more info, in particular on specifying correct priors for factors
+#' with more than 2 levels, see
+#' \href{https://easystats.github.io/bayestestR/articles/bayes_factors.html}{the
+#' Bayes factors vignette}.}
 #'
-#' @param posterior A numerical vector, \code{stanreg} / \code{brmsfit} object, \code{emmGrid}
-#' or a data frame - representing a posterior distribution(s) from (see 'Details').
+#' @param posterior A numerical vector, \code{stanreg} / \code{brmsfit} object,
+#'   \code{emmGrid} or a data frame - representing a posterior distribution(s)
+#'   from (see 'Details').
 #' @param prior An object representing a prior distribution (see 'Details').
-#' @param direction Test type (see 'Details'). One of \code{0}, \code{"two-sided"} (default, two tailed),
-#' \code{-1}, \code{"left"} (left tailed) or \code{1}, \code{"right"} (right tailed).
+#' @param direction Test type (see 'Details'). One of \code{0},
+#'   \code{"two-sided"} (default, two tailed), \code{-1}, \code{"left"} (left
+#'   tailed) or \code{1}, \code{"right"} (right tailed).
 #' @param null Value of the null, either a scalar (for point-null) or a range
-#' (for a interval-null).
-#' @param ... Arguments passed to and from other methods.
-#'   (Can be used to pass arguments to internal \code{\link[logspline]{logspline}}.)
+#'   (for a interval-null).
+#' @param ... Arguments passed to and from other methods. (Can be used to pass
+#'   arguments to internal \code{\link[logspline]{logspline}}.)
 #' @inheritParams hdi
 #'
-#' @return A data frame containing the Bayes factor representing evidence \emph{against} the null.
+#' @return A data frame containing the Bayes factor representing evidence
+#'   \emph{against} the null.
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a
+#'   \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method}
+#'   implemented in the
+#'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
-#' @details This method is used to compute Bayes factors based on prior and posterior distributions.
+#' @details
+#' This method is used to compute Bayes factors based on prior and posterior
+#' distributions.
 #'
-#' \subsection{One-sided Tests (setting an order restriction)}{
-#' One sided tests (controlled by \code{direction}) are conducted by restricting the prior and
-#' posterior of the non-null values (the "alternative") to one side of the null only
-#' (\cite{Morey & Wagenmakers, 2014}). For example, if we have a prior hypothesis that the
-#' parameter should be positive, the alternative will be restricted to the region to the right
-#' of the null (point or interval).
+#' \subsection{One-sided & Dividing Tests (setting an order restriction)}{
+#' One sided tests (controlled by \code{direction}) are conducted by restricting
+#' the prior and posterior of the non-null values (the "alternative") to one
+#' side of the null only (\cite{Morey & Wagenmakers, 2014}). For example, if we
+#' have a prior hypothesis that the parameter should be positive, the
+#' alternative will be restricted to the region to the right of the null (point
+#' or interval). For example, for a Bayes factor comparing the "null" of [0-0.1]
+#' to the alternative [>0.1], we would set
+#' \code{bayesfactor_parameters(null = c(0, 0.1), direction = ">")}.
+#' \cr\cr
+#' It is also possible to compute a Bayes factor for \strong{dividing}
+#' hypotheses - that is, for a null and alternative that are complementary,
+#' opposing one-sided hypotheses (\cite{Morey & Wagenmakers, 2014}). For
+#' example, for a Bayes factor comparing the "null" of [<0] to the alternative
+#' [>0], we would set \code{bayesfactor_parameters(null = c(-Inf, 0))}.
 #' }
 #'
 #' @section Setting the correct \code{prior}:
-#' For the computation of Bayes factors, the model priors must be proper priors (at the very least
-#' they should be \emph{not flat}, and it is preferable that they be \emph{informative}); As the priors for
-#' the alternative get wider, the likelihood of the null value(s) increases, to the extreme that for completely
-#' flat priors the null is infinitely more favorable than the alternative (this is called \emph{the Jeffreys-Lindley-Bartlett
-#' paradox}). Thus, you should only ever try (or want) to compute a Bayes factor when you have an informed prior.
+#' For the computation of Bayes factors, the model priors must be proper priors
+#' (at the very least they should be \emph{not flat}, and it is preferable that
+#' they be \emph{informative}); As the priors for the alternative get wider, the
+#' likelihood of the null value(s) increases, to the extreme that for completely
+#' flat priors the null is infinitely more favorable than the alternative (this
+#' is called \emph{the Jeffreys-Lindley-Bartlett paradox}). Thus, you should
+#' only ever try (or want) to compute a Bayes factor when you have an informed
+#' prior.
 #' \cr\cr
-#' (Note that by default, \code{brms::brm()} uses flat priors for fixed-effects; See example below.)
+#' (Note that by default, \code{brms::brm()} uses flat priors for fixed-effects;
+#' See example below.)
 #' \cr\cr
 #' It is important to provide the correct \code{prior} for meaningful results.
 #' \itemize{
@@ -74,23 +101,23 @@
 #' }
 #'
 #' @section Interpreting Bayes Factors:
-#' A Bayes factor greater than 1 can be interpreted as evidence against the null,
-#' at which one convention is that a Bayes factor greater than 3 can be considered
-#' as "substantial" evidence against the null (and vice versa, a Bayes factor
-#' smaller than 1/3 indicates substantial evidence in favor of the null-model)
-#' (\cite{Wetzels et al. 2011}).
+#' A Bayes factor greater than 1 can be interpreted as evidence against the
+#' null, at which one convention is that a Bayes factor greater than 3 can be
+#' considered as "substantial" evidence against the null (and vice versa, a
+#' Bayes factor smaller than 1/3 indicates substantial evidence in favor of the
+#' null-model) (\cite{Wetzels et al. 2011}).
 #'
 #' @examples
 #' library(bayestestR)
-#'
-#' prior <- distribution_normal(1000, mean = 0, sd = 1)
-#' posterior <- distribution_normal(1000, mean = .5, sd = .3)
-#'
-#' bayesfactor_parameters(posterior, prior)
+#' if (require("logspline")) {
+#'   prior <- distribution_normal(1000, mean = 0, sd = 1)
+#'   posterior <- distribution_normal(1000, mean = .5, sd = .3)
+#'   bayesfactor_parameters(posterior, prior)
+#' }
 #' \dontrun{
 #' # rstanarm models
 #' # ---------------
-#' if (require("rstanarm") && require("emmeans")) {
+#' if (require("rstanarm") && require("emmeans") && require("logspline")) {
 #'   contrasts(sleep$group) <- contr.bayes # see vingette
 #'   stan_model <- stan_lmer(extra ~ group + (1 | ID), data = sleep)
 #'   bayesfactor_parameters(stan_model)
@@ -136,7 +163,7 @@ bayesfactor_parameters <- function(posterior, prior = NULL, direction = "two-sid
 
 #' @rdname bayesfactor_parameters
 #' @export
-bayesfactor_pointull <- function(posterior, prior = NULL, direction = "two-sided", null = 0, verbose = TRUE, ...) {
+bayesfactor_pointnull <- function(posterior, prior = NULL, direction = "two-sided", null = 0, verbose = TRUE, ...) {
   if (length(null) > 1) {
     message("'null' is a range - computing a ROPE based Bayes factor.")
   }
@@ -174,7 +201,7 @@ bf_parameters <- bayesfactor_parameters
 
 #' @rdname bayesfactor_parameters
 #' @export
-bf_pointull <- bayesfactor_pointull
+bf_pointnull <- bayesfactor_pointnull
 
 #' @rdname bayesfactor_parameters
 #' @export
@@ -218,7 +245,7 @@ bayesfactor_parameters.stanreg <- function(posterior,
                                            null = 0,
                                            verbose = TRUE,
                                            effects = c("fixed", "random", "all"),
-                                           component = c("conditional", "zi", "zero_inflated", "all"),
+                                           component = c("conditional", "location", "smooth_terms", "sigma", "zi", "zero_inflated", "all"),
                                            parameters = NULL,
                                            ...) {
   cleaned_parameters <- insight::clean_parameters(posterior)
@@ -240,6 +267,7 @@ bayesfactor_parameters.stanreg <- function(posterior,
   bf_val <- .prepare_output(temp, cleaned_parameters, inherits(posterior, "stanmvreg"))
 
   class(bf_val) <- class(temp)
+  attr(bf_val, "clean_parameters") <- cleaned_parameters
   attr(bf_val, "hypothesis") <- attr(temp, "hypothesis") # don't change the name of this attribute - it is used only internally for "see" and printing
   attr(bf_val, "direction") <- attr(temp, "direction")
   attr(bf_val, "plot_data") <- attr(temp, "plot_data")
@@ -254,8 +282,37 @@ bayesfactor_parameters.stanreg <- function(posterior,
 bayesfactor_parameters.brmsfit <- bayesfactor_parameters.stanreg
 
 
-
 #' @rdname bayesfactor_parameters
+#' @export
+bayesfactor_parameters.blavaan <- function(posterior,
+                                           prior = NULL,
+                                           direction = "two-sided",
+                                           null = 0,
+                                           verbose = TRUE,
+                                           ...) {
+  cleaned_parameters <- insight::clean_parameters(posterior)
+
+  samps <- .clean_priors_and_posteriors(posterior, prior,
+                                        verbose = verbose)
+
+  # Get BFs
+  temp <- bayesfactor_parameters.data.frame(
+    posterior = samps$posterior, prior = samps$prior,
+    direction = direction, null = null, ...
+  )
+
+  bf_val <- .prepare_output(temp, cleaned_parameters)
+
+  class(bf_val) <- class(temp)
+  attr(bf_val, "clean_parameters") <- cleaned_parameters
+  attr(bf_val, "hypothesis") <- attr(temp, "hypothesis") # don't change the name of this attribute - it is used only internally for "see" and printing
+  attr(bf_val, "direction") <- attr(temp, "direction")
+  attr(bf_val, "plot_data") <- attr(temp, "plot_data")
+
+  bf_val
+}
+
+
 #' @export
 bayesfactor_parameters.emmGrid <- function(posterior,
                                            prior = NULL,
