@@ -75,7 +75,7 @@ ci <- function(x, ...) {
 
 
 #' @keywords internal
-.ci_bayesian <- function(x, ci = .89, method = "ETI", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, BF = 1, ...) {
+.ci_bayesian <- function(x, ci = 0.95, method = "ETI", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, verbose = TRUE, BF = 1, ...) {
   if (tolower(method) %in% c("eti", "equal", "ci", "quantile")) {
     return(eti(x, ci = ci, effects = effects, component = component, parameters = parameters, verbose = verbose, ...))
   } else if (tolower(method) %in% c("hdi")) {
@@ -87,14 +87,14 @@ ci <- function(x, ...) {
   }
 }
 
+
 #' @rdname ci
 #' @export
-ci.numeric <- function(x, ci = .89, method = "ETI", verbose = TRUE, BF = 1, ...) {
+ci.numeric <- function(x, ci = 0.95, method = "ETI", verbose = TRUE, BF = 1, ...) {
   .ci_bayesian(x, ci = ci, method = method, verbose = verbose, BF = BF, ...)
 }
 
 
-
 #' @rdname ci
 #' @export
 ci.data.frame <- ci.numeric
@@ -112,7 +112,7 @@ ci.emmGrid <- function(x, ci = NULL, ...) {
     return(parameters::ci_wald(model = x, ci = ci, dof = parameters::degrees_of_freedom(x), ...))
   }
 
-  if (is.null(ci)) ci <- 0.89
+  if (is.null(ci)) ci <- 0.95
   x <- insight::get_parameters(x)
   ci(x, ci = ci, ...)
 }
@@ -125,7 +125,7 @@ ci.emm_list <- ci.emmGrid
 
 #' @rdname ci
 #' @export
-ci.sim.merMod <- function(x, ci = .89, method = "ETI", effects = c("fixed", "random", "all"),
+ci.sim.merMod <- function(x, ci = 0.95, method = "ETI", effects = c("fixed", "random", "all"),
                           parameters = NULL, verbose = TRUE, ...) {
   .ci_bayesian(x, ci = ci, method = method, effects = effects, parameters = parameters, verbose = verbose, ...)
 }
@@ -134,7 +134,7 @@ ci.sim.merMod <- function(x, ci = .89, method = "ETI", effects = c("fixed", "ran
 
 #' @rdname ci
 #' @export
-ci.sim <- function(x, ci = .89, method = "ETI", parameters = NULL, verbose = TRUE, ...) {
+ci.sim <- function(x, ci = 0.95, method = "ETI", parameters = NULL, verbose = TRUE, ...) {
   .ci_bayesian(x, ci = ci, method = method, parameters = parameters, verbose = verbose, ...)
 }
 
@@ -142,15 +142,16 @@ ci.sim <- function(x, ci = .89, method = "ETI", parameters = NULL, verbose = TRU
 
 #' @rdname ci
 #' @export
-ci.stanreg <- function(x, ci = .89, method = "ETI", effects = c("fixed", "random", "all"),
+ci.stanreg <- function(x, ci = 0.95, method = "ETI", effects = c("fixed", "random", "all"),
+                       component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
                        parameters = NULL, verbose = TRUE, BF = 1, ...) {
-  .ci_bayesian(x, ci = ci, method = method, effects = effects, parameters = parameters, verbose = verbose, BF = BF, ...)
+  .ci_bayesian(x, ci = ci, method = method, effects = effects, component = component, parameters = parameters, verbose = verbose, BF = BF, ...)
 }
 
 
 #' @rdname ci
 #' @export
-ci.brmsfit <- function(x, ci = .89, method = "ETI", effects = c("fixed", "random", "all"),
+ci.brmsfit <- function(x, ci = 0.95, method = "ETI", effects = c("fixed", "random", "all"),
                        component = c("conditional", "zi", "zero_inflated", "all"),
                        parameters = NULL, verbose = TRUE, BF = 1, ...) {
   .ci_bayesian(x, ci = ci, method = method, effects = effects, component = component, parameters = parameters, verbose = verbose, BF = BF, ...)
@@ -161,6 +162,10 @@ ci.brmsfit <- function(x, ci = .89, method = "ETI", effects = c("fixed", "random
 ci.stanfit <- ci.stanreg
 
 
+#' @export
+ci.blavaan <- ci.stanreg
+
+
 #' @rdname ci
 #' @export
 ci.BFBayesFactor <- ci.numeric
@@ -170,26 +175,40 @@ ci.BFBayesFactor <- ci.numeric
 
 #' @rdname ci
 #' @export
-ci.MCMCglmm <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
+ci.MCMCglmm <- function(x, ci = 0.95, method = "ETI", verbose = TRUE, ...) {
   nF <- x$Fixed$nfl
   ci(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), ci = ci, method = method, verbose = verbose, ...)
 }
 
 
-
 #' @export
-ci.mcmc <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
-  ci(as.data.frame(x), ci = ci, method = method, verbose = verbose, ...)
+ci.bamlss <- function(x, ci = 0.95, method = "ETI", component = c("all", "conditional", "location"), verbose = TRUE, ...) {
+  component <- match.arg(component)
+  ci(insight::get_parameters(x, component = component), ci = ci, method = method, verbose = verbose, ...)
 }
 
 
 #' @export
-ci.bcplm <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
+ci.bcplm <- function(x, ci = 0.95, method = "ETI", verbose = TRUE, ...) {
   ci(insight::get_parameters(x), ci = ci, method = method, verbose = verbose, ...)
 }
 
 
 #' @export
-ci.mcmc.list <- function(x, ci = .89, method = "ETI", verbose = TRUE, ...) {
-  ci(insight::get_parameters(x), ci = ci, method = method, verbose = verbose, ...)
-}
+ci.blrm <- ci.bcplm
+
+
+#' @export
+ci.mcmc <- ci.bcplm
+
+
+#' @export
+ci.mcmc.list <- ci.bcplm
+
+
+#' @export
+ci.BGGM <- ci.bcplm
+
+
+#' @export
+ci.get_predicted <- ci.data.frame
