@@ -32,9 +32,7 @@
 #' library(BayesFactor)
 #' bf <- ttestBF(x = rnorm(100, 1, 1))
 #' p_map(bf)
-#' }
 #'
-#' \donttest{
 #' # ---------------------------------------
 #' # Robustness to density estimation method
 #' set.seed(333)
@@ -158,10 +156,34 @@ p_map.mcmc <- function(x, precision = 2^10, method = "kernel", parameters = NULL
 #' @export
 p_map.bcplm <- p_map.mcmc
 
+#' @export
+p_map.blrm <- p_map.mcmc
 
 #' @export
 p_map.mcmc.list <- p_map.mcmc
 
+#' @export
+p_map.BGGM <- p_map.mcmc
+
+
+
+#' @export
+p_map.bamlss <- function(x, precision = 2^10, method = "kernel", component = c("all", "conditional", "location"), parameters = NULL, ...) {
+  component <- match.arg(component)
+  out <- .p_map_models(
+    x = x,
+    precision = precision,
+    method = method,
+    effects = "all",
+    component = component,
+    parameters = parameters,
+    ...
+  )
+
+  out <- .add_clean_parameters_attribute(out, x)
+  attr(out, "data") <- insight::get_parameters(x, parameters = parameters)
+  out
+}
 
 
 
@@ -207,15 +229,18 @@ p_map.sim <- function(x, precision = 2^10, method = "kernel", parameters = NULL,
 
 #' @rdname p_map
 #' @export
-p_map.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), parameters = NULL, ...) {
+p_map.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
   effects <- match.arg(effects)
+  component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
-    p_map(insight::get_parameters(x, effects = effects, parameters = parameters), precision = precision, method = method),
-    insight::clean_parameters(x),
+    p_map(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), precision = precision, method = method),
+    cleaned_parameters,
     inherits(x, "stanmvreg")
   )
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("p_map", class(out)))
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
@@ -225,18 +250,24 @@ p_map.stanreg <- function(x, precision = 2^10, method = "kernel", effects = c("f
 p_map.stanfit <- p_map.stanreg
 
 
+#' @export
+p_map.blavaan <- p_map.stanreg
+
+
 
 #' @rdname p_map
 #' @export
 p_map.brmsfit <- function(x, precision = 2^10, method = "kernel", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
     p_map(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), precision = precision, method = method, ...),
-    insight::clean_parameters(x)
+    cleaned_parameters
   )
 
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("p_map", class(out)))
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   out
