@@ -4,6 +4,7 @@
 #'
 #' @param centrality The point-estimates (centrality indices) to compute.  Character (vector) or list with one or more of these options: \code{"median"}, \code{"mean"}, \code{"MAP"} or \code{"all"}.
 #' @param dispersion Logical, if \code{TRUE}, computes indices of dispersion related to the estimate(s) (\code{SD} and \code{MAD} for \code{mean} and \code{median}, respectively).
+#' @param threshold For \code{centrality = "trimmed"} (i.e. trimmed mean), indicates the fraction (0 to 0.5) of observations to be trimmed from each end of the vector before the mean is computed.
 #' @param ... Additional arguments to be passed to or from methods.
 #' @inheritParams hdi
 #'
@@ -58,9 +59,10 @@ point_estimate <- function(x, centrality = "all", dispersion = FALSE, ...) {
 
 
 
+#' @rdname point_estimate
 #' @export
-point_estimate.numeric <- function(x, centrality = "all", dispersion = FALSE, ...) {
-  centrality <- match.arg(tolower(centrality), c("median", "mean", "map", "all"), several.ok = TRUE)
+point_estimate.numeric <- function(x, centrality = "all", dispersion = FALSE, threshold = .1, ...) {
+  centrality <- match.arg(tolower(centrality), c("median", "mean", "map", "trimmed", "all"), several.ok = TRUE)
   if ("all" %in% centrality) {
     estimate_list <- c("median", "mean", "map")
   } else {
@@ -85,6 +87,14 @@ point_estimate.numeric <- function(x, centrality = "all", dispersion = FALSE, ..
     }
   }
 
+  # trimmed mean
+  if ("trimmed" %in% estimate_list) {
+    out$Trimmed_Mean <- mean(x, trim = threshold)
+    if (dispersion) {
+      out$SD <- stats::sd(x)
+    }
+  }
+
   # MAP
   if ("map" %in% estimate_list) {
     out$MAP <- as.numeric(map_estimate(x))
@@ -101,11 +111,11 @@ point_estimate.numeric <- function(x, centrality = "all", dispersion = FALSE, ..
 
 
 #' @export
-point_estimate.data.frame <- function(x, centrality = "all", dispersion = FALSE, ...) {
+point_estimate.data.frame <- function(x, centrality = "all", dispersion = FALSE, threshold = .1, ...) {
   x <- .select_nums(x)
 
   if (ncol(x) == 1) {
-    estimates <- point_estimate(x[, 1], centrality = centrality, dispersion = dispersion, ...)
+    estimates <- point_estimate(x[, 1], centrality = centrality, dispersion = dispersion, threshold = threshold, ...)
   } else {
     estimates <- sapply(x, point_estimate, centrality = centrality, dispersion = dispersion, simplify = FALSE, ...)
     estimates <- do.call(rbind, estimates)
@@ -136,10 +146,27 @@ point_estimate.bcplm <- function(x, centrality = "all", dispersion = FALSE, ...)
 point_estimate.bayesQR <- point_estimate.bcplm
 
 
+#' @export
+point_estimate.blrm <- point_estimate.bcplm
+
+
 #' @export
 point_estimate.mcmc.list <- point_estimate.bcplm
 
 
+#' @export
+point_estimate.BGGM <- point_estimate.bcplm
+
+
+#' @export
+point_estimate.bamlss <- function(x, centrality = "all", dispersion = FALSE, component = c("conditional", "location", "all"), ...) {
+  component <- match.arg(component)
+  out <- point_estimate(insight::get_parameters(x, component = component), centrality = centrality, dispersion = dispersion, ...)
+  out <- .add_clean_parameters_attribute(out, x)
+  out
+}
+
+
 #' @export
 point_estimate.MCMCglmm <- function(x, centrality = "all", dispersion = FALSE, ...) {
   nF <- x$Fixed$nfl
@@ -160,12 +187,14 @@ point_estimate.emmGrid <- function(x, centrality = "all", dispersion = FALSE, ..
 point_estimate.emm_list <- point_estimate.emmGrid
 
 
+# Helper ------------------------------------------------------------------
+
+
 
 #' @importFrom insight get_parameters
 #' @keywords internal
 .point_estimate_models <- function(x, effects, component, parameters, centrality = "all", dispersion = FALSE, ...) {
   out <- point_estimate(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), centrality = centrality, dispersion = dispersion, ...)
-  # out$Parameter <- .get_parameter_names(x, effects = effects, component = component, parameters = parameters)
   out
 }
 
@@ -173,17 +202,20 @@ point_estimate.emm_list <- point_estimate.emmGrid
 #' @importFrom insight get_parameters clean_parameters
 #' @rdname point_estimate
 #' @export
-point_estimate.stanreg <- function(x, centrality = "all", dispersion = FALSE, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
+point_estimate.stanreg <- function(x, centrality = "all", dispersion = FALSE, effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
   effects <- match.arg(effects)
+  component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
-    point_estimate(insight::get_parameters(x, effects = effects, parameters = parameters), centrality = centrality, dispersion = dispersion, ...),
-    insight::clean_parameters(x),
+    point_estimate(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), centrality = centrality, dispersion = dispersion, ...),
+    cleaned_parameters,
     inherits(x, "stanmvreg")
   )
 
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   attr(out, "centrality") <- centrality
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
@@ -192,20 +224,25 @@ point_estimate.stanreg <- function(x, centrality = "all", dispersion = FALSE, ef
 #' @export
 point_estimate.stanfit <- point_estimate.stanreg
 
+#' @export
+point_estimate.blavaan <- point_estimate.stanreg
+
 
 #' @rdname point_estimate
 #' @export
 point_estimate.brmsfit <- function(x, centrality = "all", dispersion = FALSE, effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
+  cleaned_parameters <- insight::clean_parameters(x)
 
   out <- .prepare_output(
     point_estimate(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), centrality = centrality, dispersion = dispersion, ...),
-    insight::clean_parameters(x)
+    cleaned_parameters
   )
 
   attr(out, "object_name") <- .safe_deparse(substitute(x))
   attr(out, "centrality") <- centrality
+  attr(out, "clean_parameters") <- cleaned_parameters
   class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
@@ -227,6 +264,7 @@ point_estimate.sim.merMod <- function(x, centrality = "all", dispersion = FALSE,
   )
   attr(out, "data") <- insight::get_parameters(x, effects = effects, parameters = parameters)
   attr(out, "centrality") <- centrality
+  out <- .add_clean_parameters_attribute(out, x)
   class(out) <- unique(c("point_estimate", "see_point_estimate", class(out)))
 
   out
@@ -264,3 +302,19 @@ point_estimate.BFBayesFactor <- function(x, centrality = "all", dispersion = FAL
 
   out
 }
+
+
+#' @export
+point_estimate.matrix <- function(x, ...) {
+  point_estimate(as.data.frame(x), ...)
+}
+
+
+#' @export
+point_estimate.get_predicted <- function(x, ...) {
+  if ("iterations" %in% names(attributes(x))) {
+    point_estimate(as.data.frame(t(attributes(x)$iterations)), ...)
+  } else{
+    as.numeric(x)
+  }
+}
