@@ -43,6 +43,28 @@
 #' @keywords internal
 .clean_priors_and_posteriors.brmsfit <- .clean_priors_and_posteriors.stanreg
 
+
+#' @keywords internal
+#' @importFrom insight get_parameters
+.clean_priors_and_posteriors.blavaan <- function(posterior, prior,
+                                                 verbose = TRUE, ...) {
+  # Get Priors
+  if (is.null(prior)) {
+    prior <- posterior
+  }
+
+  prior <- unupdate(prior, verbose = verbose)
+
+  prior <- insight::get_parameters(prior)
+  posterior <- insight::get_parameters(posterior)
+
+  list(
+    posterior = posterior,
+    prior = prior
+  )
+}
+
+
 #' @keywords internal
 #' @importFrom stats update
 .clean_priors_and_posteriors.emmGrid <- function(posterior, prior,
@@ -184,6 +206,51 @@
   df.model
 }
 
+#' @keywords internal
+.make_terms <- function(formula) {
+  sort_interactions <- function(x) {
+    if (grepl("\\:", x)) {
+      effs <- unlist(strsplit(x, "\\:"))
+      x <- paste0(sort(effs), collapse = ":")
+    }
+    x
+  }
+  formula.f <- stats::as.formula(paste0("~", formula))
+  all.terms <- attr(stats::terms(formula.f), "term.labels")
+
+  # Fixed
+  fix_trms <- all.terms[!grepl("\\|", all.terms)] # no random
+  if (length(fix_trms) > 0) {
+    fix_trms <- sapply(fix_trms, sort_interactions)
+  }
+
+  # Random
+  random_parts <- paste0(all.terms[grepl("\\|", all.terms)]) # only random
+  if (length(random_parts) == 0) {
+    return(fix_trms)
+  }
+  random_units <- sub("^.+\\|\\s+", "", random_parts)
+  tmp_random <- lapply(
+    sub("\\|.+$", "", random_parts),
+    function(x) stats::as.formula(paste0("~", x))
+  )
+
+  rand_trms <- vector("list", length(random_parts))
+
+  for (i in seq_along(random_parts)) {
+    tmp_trms <- attr(stats::terms.formula(tmp_random[[i]]), "term.labels")
+    tmp_trms <- sapply(tmp_trms, sort_interactions)
+
+    if (!any(unlist(strsplit(as.character(tmp_random[[i]])[[2]], " \\+ ")) == "0")) {
+      tmp_trms <- c("1", tmp_trms)
+    }
+
+    rand_trms[[i]] <- paste0(tmp_trms, ":", random_units[[i]])
+  }
+
+  c(fix_trms, unlist(rand_trms))
+}
+
 # make_BF_plot_data -------------------------------------------------------
 
 #' @importFrom stats median mad approx
@@ -210,12 +277,13 @@
         max(c(x_range[1], x_rangex[1])),
         min(c(x_range[2], x_rangex[2]))
       )
+      x_range <- range(c(x_range, null)[!is.infinite(c(x_range, null))])
 
       extension_scale <- diff(x_range) * extend_scale
-      x_range[1] <- x_range[1] - extension_scale
-      x_range[2] <- x_range[2] + extension_scale
+      x_range <- x_range + c(-1, 1) * extension_scale
 
       x_axis <- seq(x_range[1], x_range[2], length.out = precision)
+      # x_axis <- sort(unique(c(x_axis, null)))
       f_x <- .logspline(x, ...)
       y <- logspline::dlogspline(x_axis, f_x)
       d_points <- data.frame(x = x_axis, y = y)
@@ -226,13 +294,21 @@
 
       # 3. direction?
       if (direction > 0) {
-        d_points <- d_points[d_points$x > min(null), , drop = FALSE]
-        norm_factor <- 1 - logspline::plogspline(min(null), f_x)
+        d_points <- d_points[d_points$x >= min(null), , drop = FALSE]
+        if (is.infinite(min(null))) {
+          norm_factor <- 1
+        } else {
+          norm_factor <- 1 - logspline::plogspline(min(null), f_x)
+        }
         d_points$y <- d_points$y / norm_factor
         d_null$y <- d_null$y / norm_factor
       } else if (direction < 0) {
-        d_points <- d_points[d_points$x < max(null), , drop = FALSE]
-        norm_factor <- logspline::plogspline(max(null), f_x)
+        d_points <- d_points[d_points$x <= max(null), , drop = FALSE]
+        if (is.infinite(max(null))) {
+          norm_factor <- 1
+        } else {
+          norm_factor <- logspline::plogspline(max(null), f_x)
+        }
         d_points$y <- d_points$y / norm_factor
         d_null$y <- d_null$y / norm_factor
       }
