@@ -1,43 +1,46 @@
 ## ----message=FALSE, warning=FALSE, include=FALSE------------------------------
+library(knitr)
+
+knitr::opts_chunk$set(comment = ">")
+options(knitr.kable.NA = "")
+options(digits = 2)
+
 if (!requireNamespace("rstanarm", quietly = TRUE)) {
   knitr::opts_chunk$set(eval = FALSE)
+} else {
+  library(rstanarm)
+  library(bayestestR)
 }
 
-library(knitr)
-options(knitr.kable.NA = '')
-knitr::opts_chunk$set(comment=">")
-options(digits=2)
-
 ## ----echo=FALSE, fig.cap="Accurate depiction of a regular Bayesian user estimating a credible interval.", fig.align='center', out.width="50%"----
 knitr::include_graphics("https://github.com/easystats/easystats/raw/master/man/figures/bayestestR/bayesianMaster.jpg")
 
 ## ----eval=FALSE, message=FALSE, warning=FALSE---------------------------------
-#  install.packages("devtools")
-#  devtools::install_github("easystats/easystats")
+#  install.packages("remotes")
+#  remotes::install_github("easystats/easystats")
 
 ## ----message=FALSE, warning=FALSE, eval=FALSE---------------------------------
 #  install.packages("rstanarm")
 #  library(rstanarm)
 
 ## ----message=FALSE, warning=FALSE, eval=FALSE---------------------------------
-#  model <- lm(Sepal.Length ~ Petal.Length, data=iris)
+#  model <- lm(Sepal.Length ~ Petal.Length, data = iris)
 #  summary(model)
 
 ## ----echo=FALSE, message=FALSE, warning=FALSE, comment=NA---------------------
-library(dplyr)
-
-lm(Sepal.Length ~ Petal.Length, data=iris) %>% 
-  summary()
+model <- lm(Sepal.Length ~ Petal.Length, data = iris)
+summary(model)
 
 ## ----message=FALSE, warning=FALSE, eval=FALSE---------------------------------
-#  model <- stan_glm(Sepal.Length ~ Petal.Length, data=iris)
-#  describe_posterior(model)
+#  model <- stan_glm(Sepal.Length ~ Petal.Length, data = iris)
+#  posteriors <- describe_posterior(model)
+#  # for a nicer table
+#  print_md(posteriors, digits = 2)
 
 ## ----echo=FALSE, message=FALSE, warning=FALSE, comment=NA---------------------
-library(rstanarm)
-library(bayestestR)
 set.seed(333)
-
-model <- stan_glm(Sepal.Length ~ Petal.Length, data=iris, refresh = 0)
-knitr::kable(describe_posterior(model), digits=2)
+model <- stan_glm(Sepal.Length ~ Petal.Length, data = iris, refresh = 0)
+posteriors <- describe_posterior(model)
+# for a nicer table
+print_md(posteriors, digits = 2)
 
